==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/signer/kotlin/inputs/SigningProfileSignatureValidityPeriodArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.signer.kotlin.inputs

import com.pulumi.aws.signer.inputs.SigningProfileSignatureValidityPeriodArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property type
 * @property value
 */
public data class SigningProfileSignatureValidityPeriodArgs(
    public val type: Output<String>,
    public val `value`: Output<Int>,
) : ConvertibleToJava<com.pulumi.aws.signer.inputs.SigningProfileSignatureValidityPeriodArgs> {
    override fun toJava(): com.pulumi.aws.signer.inputs.SigningProfileSignatureValidityPeriodArgs =
        com.pulumi.aws.signer.inputs.SigningProfileSignatureValidityPeriodArgs.builder()
            .type(type.applyValue({ args0 -> args0 }))
            .`value`(`value`.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [SigningProfileSignatureValidityPeriodArgs].
 */
@PulumiTagMarker
public class SigningProfileSignatureValidityPeriodArgsBuilder internal constructor() {
    private var type: Output<String>? = null

    private var `value`: Output<Int>? = null

    /**
     * @param value
     */
    @JvmName("xllkxysoptsjvnrj")
    public suspend fun type(`value`: Output<String>) {
        this.type = value
    }

    /**
     * @param value
     */
    @JvmName("nypdylxrohmloild")
    public suspend fun `value`(`value`: Output<Int>) {
        this.`value` = value
    }

    /**
     * @param value
     */
    @JvmName("knrgsxnpxcfiqbyl")
    public suspend fun type(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.type = mapped
    }

    /**
     * @param value
     */
    @JvmName("xalvrxkcdidaidly")
    public suspend fun `value`(`value`: Int) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.`value` = mapped
    }

    internal fun build(): SigningProfileSignatureValidityPeriodArgs =
        SigningProfileSignatureValidityPeriodArgs(
            type = type ?: throw PulumiNullFieldException("type"),
            `value` = `value` ?: throw PulumiNullFieldException("value"),
        )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/signer/kotlin/inputs/SigningProfileSignatureValidityPeriodArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.signer.kotlin.inputs

import com.pulumi.aws.signer.inputs.SigningProfileSignatureValidityPeriodArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property type The time unit for signature validity. Valid values: `DAYS`, `MONTHS`, `YEARS`.
 * @property value The numerical value of the time unit for signature validity.
 */
public data class SigningProfileSignatureValidityPeriodArgs(
    public val type: Output<String>,
    public val `value`: Output<Int>,
) : ConvertibleToJava<com.pulumi.aws.signer.inputs.SigningProfileSignatureValidityPeriodArgs> {
    override fun toJava(): com.pulumi.aws.signer.inputs.SigningProfileSignatureValidityPeriodArgs =
        com.pulumi.aws.signer.inputs.SigningProfileSignatureValidityPeriodArgs.builder()
            .type(type.applyValue({ args0 -> args0 }))
            .`value`(`value`.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [SigningProfileSignatureValidityPeriodArgs].
 */
@PulumiTagMarker
public class SigningProfileSignatureValidityPeriodArgsBuilder internal constructor() {
    private var type: Output<String>? = null

    private var `value`: Output<Int>? = null

    /**
     * @param value The time unit for signature validity. Valid values: `DAYS`, `MONTHS`, `YEARS`.
     */
    @JvmName("rdhpkjtnmrrampys")
    public suspend fun type(`value`: Output<String>) {
        this.type = value
    }

    /**
     * @param value The numerical value of the time unit for signature validity.
     */
    @JvmName("nxjnublxvrthlwqn")
    public suspend fun `value`(`value`: Output<Int>) {
        this.`value` = value
    }

    /**
     * @param value The time unit for signature validity. Valid values: `DAYS`, `MONTHS`, `YEARS`.
     */
    @JvmName("wmtgthtwdrwinjrc")
    public suspend fun type(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.type = mapped
    }

    /**
     * @param value The numerical value of the time unit for signature validity.
     */
    @JvmName("cugpivdttwuqdboj")
    public suspend fun `value`(`value`: Int) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.`value` = mapped
    }

    internal fun build(): SigningProfileSignatureValidityPeriodArgs =
        SigningProfileSignatureValidityPeriodArgs(
            type = type ?: throw PulumiNullFieldException("type"),
            `value` = `value` ?: throw PulumiNullFieldException("value"),
        )
}
